@@ -9,7 +9,7 @@ from kombu import Connection
 from mock import patch, Mock, call
 
 from nameko.containers import (
-    ServiceContainer, WorkerContext, WorkerContextBase, NAMEKO_CONTEXT_KEYS)
+    ServiceContainer, WorkerContextBase, NAMEKO_CONTEXT_KEYS)
 from nameko.dependencies import InjectionProvider, injection, DependencyFactory
 from nameko.events import event_handler
 from nameko.exceptions import (
@@ -19,7 +19,7 @@ from nameko.rpc import (
     rpc, rpc_proxy, RpcConsumer, RpcProvider, ReplyListener)
 from nameko.standalone.rpc import RpcProxy
 from nameko.testing.services import entrypoint_hook
-from nameko.testing.utils import get_dependency
+from nameko.testing.utils import get_dependency, wait_for_call
 
 
 class ExampleError(Exception):
@@ -374,8 +374,7 @@ def test_rpc_existing_method(container_factory, rabbit_config):
         assert proxy.task_b() == "result_b"
 
 
-@pytest.yield_fixture
-def argtest_container(rabbit_config):
+def test_rpc_incorrect_signature(container_factory, rabbit_config):
 
     class Service(object):
 
@@ -407,55 +406,52 @@ def argtest_container(rabbit_config):
         def args_star_kwargs(self, a, **kwargs):
             pass
 
-    container = ServiceContainer(Service, WorkerContext, rabbit_config)
+    container = container_factory(Service, rabbit_config)
     container.start()
-    yield container
-    container.stop()
 
+    method_calls = [
+        (('no_args', (), {}), None),
+        (('no_args', ('bad arg',), {}),
+            "no_args() takes no arguments (1 given)"),
+        (('args_only', ('arg',), {}), None),
+        (('args_only', (), {'a': 'arg'}), None),
+        (('args_only', (), {'arg': 'arg'}),
+            "args_only() got an unexpected keyword argument 'arg'"),
+        (('kwargs_only', ('a',), {}), None),
+        (('kwargs_only', (), {'a': 'arg'}), None),
+        (('kwargs_only', (), {'arg': 'arg'}),
+            "kwargs_only() got an unexpected keyword argument 'arg'"),
+        (('star_args', ('a', 'b'), {}), None),
+        (('star_args', (), {'c': 'c'}),
+            "star_args() got an unexpected keyword argument 'c'"),
+        (('args_star_args', ('a',), {}), None),
+        (('args_star_args', ('a', 'b'), {}), None),
+        (('args_star_args', (), {}),
+            "args_star_args() takes at least 1 argument (0 given)"),
+        (('args_star_args', (), {'c': 'c'}),
+            "args_star_args() got an unexpected keyword argument 'c'"),
+        (('args_star_kwargs', ('a',), {}), None),
+        (('args_star_kwargs', ('a', 'b'), {}),
+            "args_star_kwargs() takes exactly 1 argument (2 given)"),
+        (('args_star_kwargs', ('a', 'b'), {'c': 'c'}),
+            "args_star_kwargs() takes exactly 1 argument (3 given)"),
+        (('args_star_kwargs', (), {}),
+            "args_star_kwargs() takes exactly 1 argument (0 given)"),
+    ]
 
-@pytest.mark.parametrize('signature, expected_error', [
-    (('no_args', (), {}), None),
-    (('no_args', ('bad arg',), {}),
-        "no_args() takes no arguments (1 given)"),
-    (('args_only', ('arg',), {}), None),
-    (('args_only', (), {'a': 'arg'}), None),
-    (('args_only', (), {'arg': 'arg'}),
-        "args_only() got an unexpected keyword argument 'arg'"),
-    (('kwargs_only', ('a',), {}), None),
-    (('kwargs_only', (), {'a': 'arg'}), None),
-    (('kwargs_only', (), {'arg': 'arg'}),
-        "kwargs_only() got an unexpected keyword argument 'arg'"),
-    (('star_args', ('a', 'b'), {}), None),
-    (('star_args', (), {'c': 'c'}),
-        "star_args() got an unexpected keyword argument 'c'"),
-    (('args_star_args', ('a',), {}), None),
-    (('args_star_args', ('a', 'b'), {}), None),
-    (('args_star_args', (), {}),
-        "args_star_args() takes at least 1 argument (0 given)"),
-    (('args_star_args', (), {'c': 'c'}),
-        "args_star_args() got an unexpected keyword argument 'c'"),
-    (('args_star_kwargs', ('a',), {}), None),
-    (('args_star_kwargs', ('a', 'b'), {}),
-        "args_star_kwargs() takes exactly 1 argument (2 given)"),
-    (('args_star_kwargs', ('a', 'b'), {'c': 'c'}),
-        "args_star_kwargs() takes exactly 1 argument (3 given)"),
-    (('args_star_kwargs', (), {}),
-        "args_star_kwargs() takes exactly 1 argument (0 given)"),
-])
-def test_rpc_incorrect_signature(
-        signature, expected_error, argtest_container, rabbit_config):
+    for signature, expected_error in method_calls:
 
-    method_name, args, kwargs = signature
+        method_name, args, kwargs = signature
 
-    with RpcProxy("service", rabbit_config) as proxy:
-        method = getattr(proxy, method_name)
+        with RpcProxy("service", rabbit_config) as proxy:
+            method = getattr(proxy, method_name)
 
-        if expected_error:
-            with pytest.raises(IncorrectSignature) as exc_info:
-                method(*args, **kwargs)
-            assert exc_info.value.message == expected_error
-        else:
-            method(*args, **kwargs)  # no raise
+            if expected_error:
+                with pytest.raises(IncorrectSignature) as exc_info:
+                    method(*args, **kwargs)
+                assert exc_info.value.message == expected_error
+            else:
+                method(*args, **kwargs)  # no raise
 
 
 def test_rpc_missing_method(container_factory, rabbit_config, rabbit_manager):
@@ -504,6 +500,34 @@ def test_rpc_unknown_service_standalone(rabbit_config, rabbit_manager):
     assert exc_info.value._service_name == 'unknown_service'
 
 
+def test_rpc_container_being_killed_retries(
+        container_factory, rabbit_config, rabbit_manager):
+
+    container = container_factory(ExampleService, rabbit_config)
+    container.start()
+
+    def wait_for_result():
+        with RpcProxy("exampleservice", rabbit_config) as proxy:
+            return proxy.task_a()
+
+    container._being_killed = True
+
+    rpc_provider = get_dependency(container, RpcProvider, name='task_a')
+
+    with patch.object(
+        rpc_provider,
+        'rpc_consumer',
+        wraps=rpc_provider.rpc_consumer,
+    ) as wrapped_consumer:
+        waiter = eventlet.spawn(wait_for_result)
+        with wait_for_call(1, wrapped_consumer.requeue_message):
+            pass  # wait until at least one message has been requeued
+        assert not waiter.dead
+
+    container._being_killed = False
+    assert waiter.wait() == 'result_a'  # now completed
+
+
 def test_rpc_responder_auto_retries(container_factory, rabbit_config,
                                     rabbit_manager):
 
